*pyobs* for Aravis cameras
==========================


Install *pyobs-aravis*
----------------------
Clone the repository:

    git clone https://github.com/pyobs/pyobs-aravis.git


Install dependencies:

    cd pyobs-aravis
    pip3 install -r requirements
        
And install it:

    python3 setup.py install


Dependencies
------------
* **pyobs** for the core funcionality. It is not included in the *requirements.txt*, so needs to be installed 
  separately.
* [Aravis](https://github.com/AravisProject/aravis) for accessing the camera.
* [python-aravis](https://github.com/SintefManufacturing/python-aravis) as an easy-to-use interface.

